Skip to contents

Downloads the monthly count of mortgage approvals for house purchase, a widely watched leading indicator of housing market activity. Available from April 1993.

Usage

boe_mortgage_approvals(
  from = "1993-04-01",
  to = Sys.Date(),
  seasonally_adjusted = TRUE,
  cache = TRUE
)

Arguments

from

Date or character (YYYY-MM-DD). Start date. Defaults to "1993-04-01".

to

Date or character (YYYY-MM-DD). End date. Defaults to today.

seasonally_adjusted

Logical. Return seasonally adjusted series (default TRUE) or non-seasonally adjusted (FALSE).

cache

Logical. Use cached data if available (default TRUE).

Value

A data frame with columns:

date

Date. End of month.

approvals

Numeric. Number of mortgage approvals.

See also

Other credit and housing: boe_consumer_credit(), boe_mortgage_rates()

Examples

# \donttest{
op <- options(boe.cache_dir = tempdir())
boe_mortgage_approvals(from = "2015-01-01")
#> ℹ Downloading from Bank of England
#> ✔ Downloading from Bank of England [421ms]
#> 
#> # BoE [boe_mortgage_approvals]: 1 series [LPMVTVX] · 139 obs · 2015-01-01 to 2026-09-19 · freq=monthly
#>           date approvals
#> 1   2015-01-31     58916
#> 2   2015-02-28     61448
#> 3   2015-03-31     62814
#> 4   2015-04-30     68967
#> 5   2015-05-31     65309
#> 6   2015-06-30     68155
#> 7   2015-07-31     70809
#> 8   2015-08-31     72208
#> 9   2015-09-30     71190
#> 10  2015-10-31     70126
#> 11  2015-11-30     70498
#> 12  2015-12-31     71266
#> 13  2016-01-31     72441
#> 14  2016-02-29     71874
#> 15  2016-03-31     70694
#> 16  2016-04-30     68741
#> 17  2016-05-31     67788
#> 18  2016-06-30     65565
#> 19  2016-07-31     62698
#> 20  2016-08-31     61401
#> 21  2016-09-30     64262
#> 22  2016-10-31     67935
#> 23  2016-11-30     68422
#> 24  2016-12-31     68381
#> 25  2017-01-31     68010
#> 26  2017-02-28     68141
#> 27  2017-03-31     68005
#> 28  2017-04-30     67038
#> 29  2017-05-31     65941
#> 30  2017-06-30     65422
#> 31  2017-07-31     68581
#> 32  2017-08-31     66847
#> 33  2017-09-30     66361
#> 34  2017-10-31     65273
#> 35  2017-11-30     65655
#> 36  2017-12-31     62319
#> 37  2018-01-31     65873
#> 38  2018-02-28     63003
#> 39  2018-03-31     63046
#> 40  2018-04-30     63246
#> 41  2018-05-31     65019
#> 42  2018-06-30     65955
#> 43  2018-07-31     64845
#> 44  2018-08-31     66750
#> 45  2018-09-30     66004
#> 46  2018-10-31     68292
#> 47  2018-11-30     64986
#> 48  2018-12-31     64425
#> 49  2019-01-31     65126
#> 50  2019-02-28     64150
#> 51  2019-03-31     62146
#> 52  2019-04-30     65822
#> 53  2019-05-31     65474
#> 54  2019-06-30     66599
#> 55  2019-07-31     67313
#> 56  2019-08-31     66055
#> 57  2019-09-30     66251
#> 58  2019-10-31     66352
#> 59  2019-11-30     66669
#> 60  2019-12-31     67640
#> 61  2020-01-31     69507
#> 62  2020-02-29     71581
#> 63  2020-03-31     56172
#> 64  2020-04-30     15888
#> 65  2020-05-31      9360
#> 66  2020-06-30     40375
#> 67  2020-07-31     66660
#> 68  2020-08-31     85230
#> 69  2020-09-30     92657
#> 70  2020-10-31    100892
#> 71  2020-11-30    107801
#> 72  2020-12-31    103399
#> 73  2021-01-31     97181
#> 74  2021-02-28     84411
#> 75  2021-03-31     80907
#> 76  2021-04-30     85102
#> 77  2021-05-31     86023
#> 78  2021-06-30     79325
#> 79  2021-07-31     72563
#> 80  2021-08-31     71056
#> 81  2021-09-30     70574
#> 82  2021-10-31     68335
#> 83  2021-11-30     69467
#> 84  2021-12-31     72795
#> 85  2022-01-31     73949
#> 86  2022-02-28     68151
#> 87  2022-03-31     68641
#> 88  2022-04-30     65749
#> 89  2022-05-31     66363
#> 90  2022-06-30     62949
#> 91  2022-07-31     62829
#> 92  2022-08-31     72198
#> 93  2022-09-30     64911
#> 94  2022-10-31     57801
#> 95  2022-11-30     46719
#> 96  2022-12-31     41509
#> 97  2023-01-31     39798
#> 98  2023-02-28     42811
#> 99  2023-03-31     50893
#> 100 2023-04-30     48637
#> 101 2023-05-31     50905
#> 102 2023-06-30     54705
#> 103 2023-07-31     49374
#> 104 2023-08-31     45321
#> 105 2023-09-30     44027
#> 106 2023-10-31     48082
#> 107 2023-11-30     50287
#> 108 2023-12-31     52530
#> 109 2024-01-31     56032
#> 110 2024-02-29     59676
#> 111 2024-03-31     61146
#> 112 2024-04-30     61208
#> 113 2024-05-31     60800
#> 114 2024-06-30     61254
#> 115 2024-07-31     62854
#> 116 2024-08-31     65361
#> 117 2024-09-30     65596
#> 118 2024-10-31     67846
#> 119 2024-11-30     65907
#> 120 2024-12-31     66942
#> 121 2025-01-31     66270
#> 122 2025-02-28     64611
#> 123 2025-03-31     63461
#> 124 2025-04-30     59736
#> 125 2025-05-31     62618
#> 126 2025-06-30     64721
#> 127 2025-07-31     65905
#> 128 2025-08-31     65278
#> 129 2025-09-30     66053
#> 130 2025-10-31     64762
#> 131 2025-11-30     64592
#> 132 2025-12-31     61395
#> 133 2026-01-31     60145
#> 134 2026-02-28     62278
#> 135 2026-03-31     62920
#> 136 2026-04-30     65044
#> 137 2026-05-31     56396
#> 138 2026-06-30     58215
#> 139 2026-07-31     56053
options(op)
# }