| boe_browse | R Documentation |
Returns the catalogue with optional category or frequency filters.
Equivalent to boe_search(query = NULL, category, frequency) but
framed as a browse / inspect action rather than a keyword search.
boe_browse(category = NULL, frequency = NULL)
category |
Character. Optional filter on the |
frequency |
Character. Optional filter on the |
A data frame with the same columns as boe_series.
boe_search(), boe_series
Other discovery:
boe_search()
# The whole catalogue
nrow(boe_browse())
# All exchange rate series
boe_browse(category = "exchange_rates")
# All monthly series
boe_browse(frequency = "monthly")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.