Skip to contents

Downloads the monthly count of mortgage approvals for house purchase, a widely watched leading indicator of housing market activity. Available from April 1993.

Usage

boe_mortgage_approvals(
  from = "1993-04-01",
  to = Sys.Date(),
  seasonally_adjusted = TRUE,
  cache = TRUE
)

Arguments

from

Date or character (YYYY-MM-DD). Start date. Defaults to "1993-04-01".

to

Date or character (YYYY-MM-DD). End date. Defaults to today.

seasonally_adjusted

Logical. Return seasonally adjusted series (default TRUE) or non-seasonally adjusted (FALSE).

cache

Logical. Use cached data if available (default TRUE).

Value

A data frame with columns:

date

Date. End of month.

approvals

Numeric. Number of mortgage approvals.

See also

Other credit and housing: boe_consumer_credit(), boe_mortgage_rates()

Examples

# \donttest{
op <- options(boe.cache_dir = tempdir())
boe_mortgage_approvals(from = "2015-01-01")
#>  Downloading from Bank of England
#>  Downloading from Bank of England [339ms]
#> 
#> # BoE [boe_mortgage_approvals]: 1 series [LPMVTVX] · 138 obs · 2015-01-01 to 2026-08-02 · freq=monthly
#>           date approvals
#> 1   2015-01-31     58918
#> 2   2015-02-28     61447
#> 3   2015-03-31     62818
#> 4   2015-04-30     68958
#> 5   2015-05-31     65300
#> 6   2015-06-30     68171
#> 7   2015-07-31     70797
#> 8   2015-08-31     72214
#> 9   2015-09-30     71189
#> 10  2015-10-31     70131
#> 11  2015-11-30     70495
#> 12  2015-12-31     71262
#> 13  2016-01-31     72434
#> 14  2016-02-29     71877
#> 15  2016-03-31     70699
#> 16  2016-04-30     68746
#> 17  2016-05-31     67789
#> 18  2016-06-30     65560
#> 19  2016-07-31     62690
#> 20  2016-08-31     61411
#> 21  2016-09-30     64260
#> 22  2016-10-31     67935
#> 23  2016-11-30     68423
#> 24  2016-12-31     68379
#> 25  2017-01-31     68011
#> 26  2017-02-28     68139
#> 27  2017-03-31     67998
#> 28  2017-04-30     67040
#> 29  2017-05-31     65948
#> 30  2017-06-30     65430
#> 31  2017-07-31     68572
#> 32  2017-08-31     66851
#> 33  2017-09-30     66363
#> 34  2017-10-31     65276
#> 35  2017-11-30     65641
#> 36  2017-12-31     62307
#> 37  2018-01-31     65871
#> 38  2018-02-28     63000
#> 39  2018-03-31     63056
#> 40  2018-04-30     63246
#> 41  2018-05-31     65030
#> 42  2018-06-30     65973
#> 43  2018-07-31     64838
#> 44  2018-08-31     66744
#> 45  2018-09-30     66000
#> 46  2018-10-31     68282
#> 47  2018-11-30     64985
#> 48  2018-12-31     64404
#> 49  2019-01-31     65118
#> 50  2019-02-28     64146
#> 51  2019-03-31     62150
#> 52  2019-04-30     65846
#> 53  2019-05-31     65486
#> 54  2019-06-30     66613
#> 55  2019-07-31     67303
#> 56  2019-08-31     66056
#> 57  2019-09-30     66247
#> 58  2019-10-31     66324
#> 59  2019-11-30     66677
#> 60  2019-12-31     67612
#> 61  2020-01-31     69489
#> 62  2020-02-29     71584
#> 63  2020-03-31     56188
#> 64  2020-04-30     15890
#> 65  2020-05-31      9364
#> 66  2020-06-30     40396
#> 67  2020-07-31     66637
#> 68  2020-08-31     85214
#> 69  2020-09-30     92657
#> 70  2020-10-31    100836
#> 71  2020-11-30    107807
#> 72  2020-12-31    103331
#> 73  2021-01-31     97161
#> 74  2021-02-28     84417
#> 75  2021-03-31     80944
#> 76  2021-04-30     85138
#> 77  2021-05-31     86063
#> 78  2021-06-30     79356
#> 79  2021-07-31     72545
#> 80  2021-08-31     71035
#> 81  2021-09-30     70551
#> 82  2021-10-31     68283
#> 83  2021-11-30     69486
#> 84  2021-12-31     72735
#> 85  2022-01-31     73937
#> 86  2022-02-28     68166
#> 87  2022-03-31     68683
#> 88  2022-04-30     65797
#> 89  2022-05-31     66407
#> 90  2022-06-30     62960
#> 91  2022-07-31     62799
#> 92  2022-08-31     72159
#> 93  2022-09-30     64885
#> 94  2022-10-31     57752
#> 95  2022-11-30     46721
#> 96  2022-12-31     41481
#> 97  2023-01-31     39796
#> 98  2023-02-28     42828
#> 99  2023-03-31     50932
#> 100 2023-04-30     48687
#> 101 2023-05-31     50964
#> 102 2023-06-30     54692
#> 103 2023-07-31     49348
#> 104 2023-08-31     45279
#> 105 2023-09-30     43999
#> 106 2023-10-31     48045
#> 107 2023-11-30     50270
#> 108 2023-12-31     52492
#> 109 2024-01-31     56027
#> 110 2024-02-29     59707
#> 111 2024-03-31     61217
#> 112 2024-04-30     61317
#> 113 2024-05-31     60898
#> 114 2024-06-30     61207
#> 115 2024-07-31     62814
#> 116 2024-08-31     65280
#> 117 2024-09-30     65526
#> 118 2024-10-31     67792
#> 119 2024-11-30     65880
#> 120 2024-12-31     66903
#> 121 2025-01-31     66247
#> 122 2025-02-28     64651
#> 123 2025-03-31     63551
#> 124 2025-04-30     59869
#> 125 2025-05-31     62779
#> 126 2025-06-30     64664
#> 127 2025-07-31     65805
#> 128 2025-08-31     65170
#> 129 2025-09-30     65983
#> 130 2025-10-31     64705
#> 131 2025-11-30     64544
#> 132 2025-12-31     61360
#> 133 2026-01-31     60129
#> 134 2026-02-28     62321
#> 135 2026-03-31     63031
#> 136 2026-04-30     65206
#> 137 2026-05-31     56565
#> 138 2026-06-30     58200
options(op)
# }