Download mortgage approvals for house purchase
Source:R/boe_mortgage_approvals.R
boe_mortgage_approvals.RdDownloads the monthly count of mortgage approvals for house purchase, a widely watched leading indicator of housing market activity. Available from April 1993.
Usage
boe_mortgage_approvals(
from = "1993-04-01",
to = Sys.Date(),
seasonally_adjusted = TRUE,
cache = TRUE
)Arguments
- from
Date or character (YYYY-MM-DD). Start date. Defaults to
"1993-04-01".- to
Date or character (YYYY-MM-DD). End date. Defaults to today.
- seasonally_adjusted
Logical. Return seasonally adjusted series (default
TRUE) or non-seasonally adjusted (FALSE).- cache
Logical. Use cached data if available (default
TRUE).
Value
A data frame with columns:
- date
Date. End of month.
- approvals
Numeric. Number of mortgage approvals.
See also
Other credit and housing:
boe_consumer_credit(),
boe_mortgage_rates()
Examples
# \donttest{
op <- options(boe.cache_dir = tempdir())
boe_mortgage_approvals(from = "2015-01-01")
#> ℹ Downloading from Bank of England
#> ✔ Downloading from Bank of England [376ms]
#>
#> # BoE [boe_mortgage_approvals]: 1 series [LPMVTVX] · 135 obs · 2015-01-01 to 2026-05-08 · freq=monthly
#> date approvals
#> 1 2015-01-31 58967
#> 2 2015-02-28 61472
#> 3 2015-03-31 62753
#> 4 2015-04-30 69043
#> 5 2015-05-31 65411
#> 6 2015-06-30 68060
#> 7 2015-07-31 70766
#> 8 2015-08-31 72266
#> 9 2015-09-30 71178
#> 10 2015-10-31 70076
#> 11 2015-11-30 70484
#> 12 2015-12-31 71272
#> 13 2016-01-31 72481
#> 14 2016-02-29 71872
#> 15 2016-03-31 70735
#> 16 2016-04-30 68702
#> 17 2016-05-31 67875
#> 18 2016-06-30 65586
#> 19 2016-07-31 62616
#> 20 2016-08-31 61426
#> 21 2016-09-30 64239
#> 22 2016-10-31 67916
#> 23 2016-11-30 68389
#> 24 2016-12-31 68367
#> 25 2017-01-31 67993
#> 26 2017-02-28 68138
#> 27 2017-03-31 68031
#> 28 2017-04-30 67128
#> 29 2017-05-31 66034
#> 30 2017-06-30 65370
#> 31 2017-07-31 68523
#> 32 2017-08-31 66883
#> 33 2017-09-30 66321
#> 34 2017-10-31 65194
#> 35 2017-11-30 65693
#> 36 2017-12-31 62308
#> 37 2018-01-31 65858
#> 38 2018-02-28 63000
#> 39 2018-03-31 63106
#> 40 2018-04-30 63311
#> 41 2018-05-31 65108
#> 42 2018-06-30 65901
#> 43 2018-07-31 64722
#> 44 2018-08-31 66775
#> 45 2018-09-30 65995
#> 46 2018-10-31 68260
#> 47 2018-11-30 64949
#> 48 2018-12-31 64438
#> 49 2019-01-31 65118
#> 50 2019-02-28 64152
#> 51 2019-03-31 62182
#> 52 2019-04-30 65919
#> 53 2019-05-31 65559
#> 54 2019-06-30 66575
#> 55 2019-07-31 67214
#> 56 2019-08-31 66014
#> 57 2019-09-30 66210
#> 58 2019-10-31 66356
#> 59 2019-11-30 66629
#> 60 2019-12-31 67588
#> 61 2020-01-31 69511
#> 62 2020-02-29 71609
#> 63 2020-03-31 56198
#> 64 2020-04-30 15952
#> 65 2020-05-31 9370
#> 66 2020-06-30 40292
#> 67 2020-07-31 66563
#> 68 2020-08-31 85174
#> 69 2020-09-30 92540
#> 70 2020-10-31 100895
#> 71 2020-11-30 107778
#> 72 2020-12-31 103382
#> 73 2021-01-31 97150
#> 74 2021-02-28 84478
#> 75 2021-03-31 81021
#> 76 2021-04-30 85462
#> 77 2021-05-31 86180
#> 78 2021-06-30 79157
#> 79 2021-07-31 72362
#> 80 2021-08-31 70893
#> 81 2021-09-30 70493
#> 82 2021-10-31 68337
#> 83 2021-11-30 69363
#> 84 2021-12-31 72794
#> 85 2022-01-31 73987
#> 86 2022-02-28 68274
#> 87 2022-03-31 68838
#> 88 2022-04-30 66145
#> 89 2022-05-31 66464
#> 90 2022-06-30 62834
#> 91 2022-07-31 62556
#> 92 2022-08-31 71962
#> 93 2022-09-30 64684
#> 94 2022-10-31 57819
#> 95 2022-11-30 46649
#> 96 2022-12-31 41489
#> 97 2023-01-31 39810
#> 98 2023-02-28 42944
#> 99 2023-03-31 51145
#> 100 2023-04-30 49113
#> 101 2023-05-31 51093
#> 102 2023-06-30 54451
#> 103 2023-07-31 49054
#> 104 2023-08-31 45085
#> 105 2023-09-30 43810
#> 106 2023-10-31 48028
#> 107 2023-11-30 50238
#> 108 2023-12-31 52523
#> 109 2024-01-31 56120
#> 110 2024-02-29 59961
#> 111 2024-03-31 61603
#> 112 2024-04-30 61925
#> 113 2024-05-31 61181
#> 114 2024-06-30 60891
#> 115 2024-07-31 62210
#> 116 2024-08-31 64824
#> 117 2024-09-30 65218
#> 118 2024-10-31 67763
#> 119 2024-11-30 65759
#> 120 2024-12-31 66957
#> 121 2025-01-31 66474
#> 122 2025-02-28 64987
#> 123 2025-03-31 64046
#> 124 2025-04-30 60744
#> 125 2025-05-31 63145
#> 126 2025-06-30 64206
#> 127 2025-07-31 64991
#> 128 2025-08-31 64565
#> 129 2025-09-30 65526
#> 130 2025-10-31 64663
#> 131 2025-11-30 64520
#> 132 2025-12-31 61487
#> 133 2026-01-31 60354
#> 134 2026-02-28 62708
#> 135 2026-03-31 63531
options(op)
# }