Download mortgage approvals for house purchase
Source:R/boe_mortgage_approvals.R
boe_mortgage_approvals.RdDownloads the monthly count of mortgage approvals for house purchase, a widely watched leading indicator of housing market activity. Available from April 1993.
Usage
boe_mortgage_approvals(
from = "1993-04-01",
to = Sys.Date(),
seasonally_adjusted = TRUE,
cache = TRUE
)Arguments
- from
Date or character (YYYY-MM-DD). Start date. Defaults to
"1993-04-01".- to
Date or character (YYYY-MM-DD). End date. Defaults to today.
- seasonally_adjusted
Logical. Return seasonally adjusted series (default
TRUE) or non-seasonally adjusted (FALSE).- cache
Logical. Use cached data if available (default
TRUE).
Value
A data frame with columns:
- date
Date. End of month.
- approvals
Numeric. Number of mortgage approvals.
See also
Other credit and housing:
boe_consumer_credit(),
boe_mortgage_rates()
Examples
# \donttest{
op <- options(boe.cache_dir = tempdir())
boe_mortgage_approvals(from = "2015-01-01")
#> ℹ Downloading from Bank of England
#> ✔ Downloading from Bank of England [308ms]
#>
#> # BoE [boe_mortgage_approvals]: 1 series [LPMVTVX] · 134 obs · 2015-01-01 to 2026-04-26 · freq=monthly
#> date approvals
#> 1 2015-01-31 58967
#> 2 2015-02-28 61472
#> 3 2015-03-31 62753
#> 4 2015-04-30 69042
#> 5 2015-05-31 65412
#> 6 2015-06-30 68060
#> 7 2015-07-31 70769
#> 8 2015-08-31 72267
#> 9 2015-09-30 71176
#> 10 2015-10-31 70077
#> 11 2015-11-30 70486
#> 12 2015-12-31 71270
#> 13 2016-01-31 72481
#> 14 2016-02-29 71872
#> 15 2016-03-31 70732
#> 16 2016-04-30 68702
#> 17 2016-05-31 67876
#> 18 2016-06-30 65587
#> 19 2016-07-31 62619
#> 20 2016-08-31 61425
#> 21 2016-09-30 64240
#> 22 2016-10-31 67918
#> 23 2016-11-30 68387
#> 24 2016-12-31 68366
#> 25 2017-01-31 67991
#> 26 2017-02-28 68137
#> 27 2017-03-31 68031
#> 28 2017-04-30 67126
#> 29 2017-05-31 66033
#> 30 2017-06-30 65372
#> 31 2017-07-31 68528
#> 32 2017-08-31 66883
#> 33 2017-09-30 66322
#> 34 2017-10-31 65194
#> 35 2017-11-30 65692
#> 36 2017-12-31 62305
#> 37 2018-01-31 65854
#> 38 2018-02-28 62998
#> 39 2018-03-31 63104
#> 40 2018-04-30 63312
#> 41 2018-05-31 65107
#> 42 2018-06-30 65903
#> 43 2018-07-31 64728
#> 44 2018-08-31 66778
#> 45 2018-09-30 65996
#> 46 2018-10-31 68262
#> 47 2018-11-30 64948
#> 48 2018-12-31 64430
#> 49 2019-01-31 65113
#> 50 2019-02-28 64149
#> 51 2019-03-31 62181
#> 52 2019-04-30 65914
#> 53 2019-05-31 65556
#> 54 2019-06-30 66587
#> 55 2019-07-31 67219
#> 56 2019-08-31 66017
#> 57 2019-09-30 66213
#> 58 2019-10-31 66359
#> 59 2019-11-30 66625
#> 60 2019-12-31 67572
#> 61 2020-01-31 69506
#> 62 2020-02-29 71605
#> 63 2020-03-31 56196
#> 64 2020-04-30 15950
#> 65 2020-05-31 9369
#> 66 2020-06-30 40303
#> 67 2020-07-31 66570
#> 68 2020-08-31 85182
#> 69 2020-09-30 92542
#> 70 2020-10-31 100904
#> 71 2020-11-30 107769
#> 72 2020-12-31 103345
#> 73 2021-01-31 97142
#> 74 2021-02-28 84473
#> 75 2021-03-31 81016
#> 76 2021-04-30 85447
#> 77 2021-05-31 86175
#> 78 2021-06-30 79185
#> 79 2021-07-31 72370
#> 80 2021-08-31 70903
#> 81 2021-09-30 70504
#> 82 2021-10-31 68337
#> 83 2021-11-30 69352
#> 84 2021-12-31 72766
#> 85 2022-01-31 73982
#> 86 2022-02-28 68270
#> 87 2022-03-31 68833
#> 88 2022-04-30 66129
#> 89 2022-05-31 66458
#> 90 2022-06-30 62857
#> 91 2022-07-31 62567
#> 92 2022-08-31 71980
#> 93 2022-09-30 64703
#> 94 2022-10-31 57814
#> 95 2022-11-30 46638
#> 96 2022-12-31 41470
#> 97 2023-01-31 39806
#> 98 2023-02-28 42943
#> 99 2023-03-31 51142
#> 100 2023-04-30 49096
#> 101 2023-05-31 51083
#> 102 2023-06-30 54469
#> 103 2023-07-31 49066
#> 104 2023-08-31 45103
#> 105 2023-09-30 43831
#> 106 2023-10-31 48019
#> 107 2023-11-30 50226
#> 108 2023-12-31 52499
#> 109 2024-01-31 56113
#> 110 2024-02-29 59962
#> 111 2024-03-31 61594
#> 112 2024-04-30 61898
#> 113 2024-05-31 61162
#> 114 2024-06-30 60897
#> 115 2024-07-31 62227
#> 116 2024-08-31 64867
#> 117 2024-09-30 65267
#> 118 2024-10-31 67902
#> 119 2024-11-30 65899
#> 120 2024-12-31 67102
#> 121 2025-01-31 66610
#> 122 2025-02-28 65114
#> 123 2025-03-31 64193
#> 124 2025-04-30 60896
#> 125 2025-05-31 63258
#> 126 2025-06-30 64289
#> 127 2025-07-31 65057
#> 128 2025-08-31 64623
#> 129 2025-09-30 65590
#> 130 2025-10-31 64661
#> 131 2025-11-30 64501
#> 132 2025-12-31 61448
#> 133 2026-01-31 60246
#> 134 2026-02-28 62584
options(op)
# }