| boe_series | R Documentation |
A reference data frame of Bank of England Statistical Database series
codes for which the package provides a named convenience function.
Used by boe_search() and boe_browse().
boe_series
A data frame with 8 columns:
Character. BoE series code (e.g. "IUDBEDR").
Character. Human-readable description.
Character. Topic grouping. One of "interest_rates",
"exchange_rates", "mortgage_market", "consumer_credit",
"monetary_aggregates".
Character. Native publication frequency
("daily", "monthly", "annual").
Character. Unit of measurement ("percent",
"millions_gbp", "currency_per_gbp", "index", "count").
Date. Earliest available observation date.
Character or NA. "SA", "NSA", or
NA if not applicable.
Character. Convenience function in the package that wraps the series.
https://www.bankofengland.co.uk/boeapps/database/
head(boe_series)
table(boe_series$category)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.