clear_cache: Clear locally cached Bank of England data

View source: R/clear_cache.R

clear_cacheR Documentation

Clear locally cached Bank of England data

Description

Removes cached data files downloaded from the Bank of England.

Usage

clear_cache(max_age_days = NULL)

Arguments

max_age_days

Numeric or NULL. If specified, only removes files older than this many days. If NULL (the default), removes all cached files.

Value

Invisibly returns the number of files removed.

Examples


# Remove files older than 7 days
clear_cache(max_age_days = 7)

# Remove everything
clear_cache()



boe documentation built on March 12, 2026, 5:07 p.m.