View source: R/boe_exchange_rate.R
| list_exchange_rates | R Documentation |
Returns a data frame of currency codes and descriptions available from the Bank of England exchange rate series.
list_exchange_rates()
A data frame with columns:
Character. ISO currency code.
Character. Currency name.
Character. BoE series code.
list_exchange_rates()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.